const scenarios = {
  1: {
    title: "Urban Planning Challenge",
    description: "You're tasked with designing a sustainable city layout for a growing population. How will you approach this complex problem?",
    decisions: [
      {
        text: "Prioritize green spaces and public transportation",
        outcome: "Your city becomes a model for sustainable living, attracting eco-conscious residents and businesses."
      },
      {
        text: "Focus on high-density housing and commercial zones",
        outcome: "The city experiences rapid growth but struggles with traffic congestion and pollution."
      }
    ],
    resources: [
      "Urban planning best practices",
      "Sustainable development principles",
      "Case studies of successful cities"
    ]
  },
  2: {
    title: "Startup Strategy Challenge",
    description: "You're launching a new tech startup. What's your approach to gaining market traction?",
    decisions: [
      {
        text: "Focus on rapid user acquisition through aggressive marketing",
        outcome: "You gain many users quickly but struggle with retention and profitability."
      },
      {
        text: "Build a core product with a small, dedicated user base",
        outcome: "Your startup grows slowly but develops a loyal customer base and strong product-market fit."
      }
    ],
    resources: [
      "Lean startup methodology",
      "Growth hacking strategies",
      "Product-market fit analysis"
    ]
  }
};

document.querySelectorAll('.scenario-card').forEach(card => {
  card.addEventListener('click', () => {
    const scenarioId = card.dataset.scenario;
    loadScenario(scenarioId);
  });
});

function loadScenario(id) {
  const scenario = scenarios[id];
  document.getElementById('scenario-title').textContent = scenario.title;
  document.getElementById('scenario-content').innerHTML = `<p>${scenario.description}</p>`;
  
  const decisionPoints = document.getElementById('decision-points');
  decisionPoints.innerHTML = scenario.decisions.map(decision => `
    <button class="decision-button" data-outcome="${decision.outcome}">${decision.text}</button>
  `).join('');
  
  document.querySelectorAll('.decision-button').forEach(button => {
    button.addEventListener('click', showOutcome);
  });
  
  document.getElementById('scenario-intro').classList.add('hidden');
  document.getElementById('scenario-container').classList.remove('hidden');
}

function showOutcome(event) {
  const outcome = event.target.dataset.outcome;
  document.getElementById('outcome-display').textContent = outcome;
}

document.getElementById('reset-scenario').addEventListener('click', () => {
  document.getElementById('scenario-container').classList.add('hidden');
  document.getElementById('scenario-intro').classList.remove('hidden');
});